#!/bin/bash
#
# Calendar generation script Copyright (C) 2004 by Romuald DELAVERGNE
# It can be redistributed under the terms of the GNU General Public License.
#

# Pques a lieu le 1er dimanche qui suit la pleine lune qui suit ou qui a lieu le jour de l'quinoxe du printemps (21 mars)
function getPaquesDay() {
	local b c d e f g h
	local jour mois year=$1

	b=$((year-1900))
	c=$((year % 19))
	d=$(((7*$c+1)/19))
	e=$(((11*$c+4-$d) % 29))
	f=$((b/4))
	g=$(((b+$f+31-$e) % 7))
	h=$((25-$e-$g))
	if [ $h -gt 0 ]; then 
		jour=$h
		mois=4
	else 
		jour=$((h+31))
		mois=3
	fi
	echo "$jour $mois"
}

lstJours=(none dimanche lundi mardi mercredi jeudi vendredi samedi)
lstMois=(none janvier fvrier mars avril mai juin juillet aot septembre octobre novembre dcembre)
lstFeries=(jourDeLAn rameaux paques lundiDePaques feteDuTravail victoire1945 ascension pentecote lundiDePentecote feteNationale assomption toussaint armistice1918 noel)
output=/tmp/calendrier.html
year=${1:-`date +%Y`}

# Jours fris fixes
jourDeLAn=(1 1 "jour de l'an")
feteDuTravail=(1 5 "fte du travail")
victoire1945=(8 5 "victoire 1945")
feteNationale=(14 7 "fte Nationale")
assomption=(15 8 "l'Assomption")
toussaint=(1 11 "la Toussaint")
armistice1918=(11 11 "armistice 1918")
noel=(25 12 "Nol")
# Pques et ses dpendances
paques=(`getPaquesDay $year` "Pques")
rameaux[0]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 7 days ago" +%-d`
rameaux[1]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 7 days ago" +%-m`
rameaux[2]="les Rameaux"
lundiDePaques[0]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 1 day" +%-d`
lundiDePaques[1]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 1 day" +%-m`
lundiDePaques[2]="lundi de Pques"
ascension[0]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 39 days" +%-d`
ascension[1]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 39 days" +%-m`
ascension[2]="l'Ascension"
pentecote[0]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 49 days" +%-d`
pentecote[1]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 49 days" +%-m`
pentecote[2]="la Pentecte"
lundiDePentecote[0]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 50 days" +%-d`
lundiDePentecote[1]=`LANG=C date --date "${paques[1]}/${paques[0]}/$year 50 days" +%-m`
lundiDePentecote[2]="lundi de Pentecte"

function firstDay() {
	local month what line days nb

	month=`LANG=C cal $1 $year`
	what=""
	echo -e "$month" | while read line; do
		case "$what" in
			"") what="month";;
			"month") what="days";;
			"days") what="week1";;
			"week1") what="week";;
		esac
		if [ "$what" = "week1" ]; then
			days=($line)
			nb=${#days[@]}
			echo "$((8-$nb))"
			exit
		fi
	done
}

function lastDay() {
	local month nb

	month=(`LANG=C cal $1 $year`)
	nb=${#month[@]}
	echo "${month[$((nb-1))]}"
}

cat > $output << EOF
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
 "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fr">
  <head>
    <meta http-equiv="Content-Type" content="text/HTML; charset=iso-8859-1"  />
    <meta http-equiv="Content-style-type" content="text/css" />
    <meta http-equiv="Content-language" content="fr" />
    <title>Calendrier $year</title>
    <link rel="stylesheet" type="text/css" href="calendrier.css" media="screen" title="Normal" />
    <link rel="stylesheet" type="text/css" href="calendrier.css" media="print" title="Normal" />
  </head>

  <body>
EOF

for s in 1 2; do
	echo "    <table>" >> $output
	for j in `seq 0 31`; do
		[ $j -eq 0 ] && echo "      <tr id=\"semestre$s\">" >> $output || echo "      <tr class=\"jour$j\">" >> $output
		for m in `seq $((s*6-5)) $((s*6))`; do
			if [ $j -eq 0 ]; then
				echo "        <th id=\"mois$m\">${lstMois[$m]}</th>" >> $output
				jour[$m]=`firstDay $m`
				lstLast[$m]=`lastDay $m`
			else
				currentDay=${jour[$m]}
				name=${lstJours[$currentDay]}
				last=${lstLast[$m]}
				if [ $j -le $last ]; then
					classFerie=""
					for f in ${lstFeries[*]}; do
						eval jourFerie='${'$f'[0]}'
						eval moisFerie='${'$f'[1]}'
						eval libelleFerie='${'$f'[2]}'
						if [ "$j" = "$jourFerie" -a "$m" = "$moisFerie" ]; then
							classFerie=" class=\"ferie\" class=\"$f\" title=\"$libelleFerie\"" 
							break
						fi
					done
					echo "        <td$classFerie class=\"$name\"><span class=\"nom-jour\">${name:0:3}</span><span class=\"num-jour\">$j</span></td>" >> $output
					[ ${jour[$m]} = 7 ] && jour[$m]=1 || jour[$m]=$((jour[$m]+1))
				else
					if [ $last -eq 30 ]; then
						echo "        <td></td>" >> $output
					else
						[ $j -eq $((last+1)) ] && echo "        <td rowspan="$((31-last))"></td>" >> $output
					fi
				fi
			fi
		done
		echo "      </tr>" >> $output
	done
	echo "    </table>" >> $output
	echo "    <br>" >> $output
done
	
cat >> $output << EOF
  </body>
</html>
EOF

exit 0
